#ifndef GUI_GNUMERIC_H
#define GUI_GNUMERIC_H

#include "gnumeric.h"

typedef struct _ItemCursor		ItemCursor;
typedef struct _ItemGrid		ItemGrid;
typedef struct _ItemBar			ItemBar;
typedef struct _ItemEdit		ItemEdit;
typedef struct _GnmPane			GnmPane;

typedef struct _SheetControlGUI		SheetControlGUI;
typedef struct _WBCGtk			WBCGtk;

typedef struct _WorkbookControlComponent  WorkbookControlComponent;

#endif /* GUI_GNUMERIC_H */
